powered by
Expand target and bait IDs of the form chrN:start-end to separate coordinate columns in the data table
add.fragment.coordinates(id.data)
data table containing columns target.id and/or bait.id to be expanded
target.id
bait.id
Data table with added coordinate columns for target and bait (as applicable).
# NOT RUN { data(bre80); add.fragment.coordinates(bre80[, .(bait.id, target.id)]); # }
Run the code above in your browser using DataLab